# Publications

Below, there is list of the publications that describe or use different components of **Crocoddyl**:

## References
<a id="1">[1]</a>
C. Mastalli, R. Budhiraja, W. Merkt, G. Saurel, B. Hammoud, M. Naveau, J. Carpentier, L. Righetti, S. Vijayakumar and N. Mansard. [Crocoddyl: An Efficient and Versatile Framework for Multi-Contact Optimal Control](https://cmastalli.github.io/publications/crocoddyl20icra.html), IEEE International Conference on Robotics and Automation (ICRA), 2020

<a id="2">[2]</a>
C. Mastalli, W. Merkt, J. Marti-Saumell, H. Ferrolho, J. Sola, N. Mansard and S. Vijayakumar. [A Feasibility-Driven Approach
to Control-Limited DDP](https://arxiv.org/pdf/2010.00411.pdf), Autonomous Robots, 2022

<a id="3">[3]</a>
C. Mastalli, S. P. Chhatoi, T. Corbères, S. Tonneau and S. Vijayakumar. [Inverse-Dynamics MPC via Nullspace Resolution](https://arxiv.org/pdf/2209.05375.pdf), IEEE Transactions on Robotics (TRO), 2023

&nbsp;

## Other references
Here, there is a list of other contributions that were possible thanks to **Crocoddyl**:

&nbsp;

*i. Optimal control:*

<a id="4">[4]</a>
R. Budhiraja, J. Carpentier, C. Mastalli and N. Mansard. [Differential Dynamic Programming for Multi-Phase Rigid Contact Dynamics](https://cmastalli.github.io/publications/mddp18.html), IEEE RAS International Conference on Humanoid Robots (ICHR), 2018

<a id="5">[5]</a>
R. Budhiraja, J. Carpentier and N. Mansard. [Dynamics Consensus between Centroidal and Whole-Body Models for Locomotion of Legged Robots](https://arxiv.org/pdf/1904.05072.pdf), IEEE International Conference on Automation and Robotics (ICRA), 2019

<a id="6">[6]</a>
J. Martin-Saumell, J. Sola, C. Mastalli, and A. Santamaria-Navarro. [Squash-Box Feasibility Driven Differential Dynamic Programming](https://cmastalli.github.io/publications/squashddp20iros.html),  IEEE/RSJ International Conference on Intelligent Robots and Systems (IROS), 2020

<a id="7">[7]</a>
S. Kleff, J. Carpentier, N. Mansard and L. Righetti, [On the Derivation of the Contact Dynamics in Arbitrary Frames: Application to Polishing with Talos](https://hal.science/hal-03758989/document), IEEE/RAS International Conference on Humanoid Robots (Humanoids), 2022


&nbsp;

*ii. Model predictive control:*

<a id="8">[8]</a>
C. Mastalli, W. Merkt, G. Xin, J. Shim, M. Mistry, I. Havoutis and S. Vijayakumar. [Agile Maneuvers in Legged Robots: a Predictive Control Approach](https://arxiv.org/pdf/2203.07554.pdf), 2022

<a id="9">[9]</a>
E. Dantec, R. Budhiraja, A. Roig, T.S. Lembono, G. Saurel, O. Stasse, P. Fernbach, S. Tonneau, S. Vijayakumar, S. Calinon, M. Taïx, N. Mansard. [Whole Body Model Predictive Control with a Memory of Motion: Experiments on a Torque-Controlled Talos](https://hal.archives-ouvertes.fr/hal-02995796/file/HAL_MPC_memory_collision.pdf), IEEE International Conference on Robotics and Automation (ICRA), 2021

<a id="10">[10]</a>
T. Corbères, T. Flayols, P.A. Léziart, R. Budhiraja, N. Mansard
[Comparison of predictive controllers for locomotion and balance recovery of quadruped robots](https://hal.laas.fr/hal-03034022/file/icra20_corberes.pdf), IEEE International Conference on Robotics and Automation (ICRA), 2021

<a id="11">[11]</a>
S. Kleff, A. Meduri, R. Budhiraja, N. Mansard and L. Righetti.
[High-Frequency Nonlinear Model Predictive Control of a Manipulator](https://hal.archives-ouvertes.fr/hal-02993058v2/document), IEEE International Conference on Robotics and Automation (ICRA), 2021

&nbsp;

*iii. Machine learning:*

<a id="12">[12]</a>
T.S. Lembono, C. Mastalli, P. Fernbach, N. Mansard and S. Calinon. [Learning How to Walk: Warm-starting Optimal Control Solver with Memory of Motion](https://cmastalli.github.io/publications/learningwalk20icra.html), IEEE International Conference on Robotics and Automation (ICRA), 2020

&nbsp;

*iv. Co-design*

<a id="13">[13]</a>
T. Dinev, C. Mastalli, V. Ivan, S. Tonneau and S. Vijayakumar. [A Versatile Co-Design Approach For Dynamic Legged Robots](https://arxiv.org/pdf/2103.04660.pdf), IEEE International Conference on Intelligent Robots and Systems, 2022

<a id="14">[14]</a>
G Fadini, T Flayols, A del Prete, N Mansard, P Souères. [Computational design of energy-efficient legged robots: Optimizing for size and actuators](https://hal.archives-ouvertes.fr/hal-02993624v2/document), IEEE International Conference on Robotics and Automation (ICRA), 2021

&nbsp;

*v. Biomechanics*

<a id="15">[15]</a>
M. Boukheddimi, R. Budhiraja, P. Souères and B. Watier.
[Anthropomorphic Gait Generation using Differential Dynamic Programming with a Reduced Number of Cost Criteria](https://www.researchgate.net/publication/341600397_Anthropomorphic_Gait_Generation_using_Differential_Dynamic_Programming_with_a_Reduced_Number_of_Cost_Criteria),  2020 8th IEEE RAS/EMBS International Conference for Biomedical Robotics and Biomechatronics (BioRob), 2020
